@@ -16,11 +16,12 @@
 #   School of Science, Tallinn University of Technology
 #  This file is part of project: IOCBIO Kinetics
 #
-from sys import version_info
-import os, sys
+import sys
+import csv
 
 from iocbio.kinetics.io.db import DatabaseInterface
 
+
 def fetch(s):
     """Query the data from the database
 
@@ -39,13 +40,13 @@ def fetch(s):
       Result of records.query - iterative rows of the results
     """
     slower = s.lower()
-    for k in ['insert ', 'create ', 'update ', 'set ', 'delete ']:
+    for k in ["insert ", "create ", "update ", "set ", "delete "]:
         if k in slower.lower():
-            print('Not allowed sql commad: %s' % k)
+            print("Not allowed sql commad: %s" % k)
             exit()
 
-    database = DatabaseInterface.get_database()
-    records = database.query(s)
+    database = DatabaseInterface()
+    records = list(database.query_to_dict(s))
     database.close()
 
     return records
@@ -61,26 +62,32 @@ def export_csv(out_file, records):
     records : iterative rows
       Result of SQL query as returned by `fetch` function
     """
-    if out_file == '-':
+    if out_file == "-":
         fh = sys.stdout
     else:
-        fh = open(out_file if out_file.endswith('.csv') else out_file+'.csv', 'w')
-    with fh as result:
-        result.write(records.export('csv'))
+        fh = open(out_file if out_file.endswith(".csv") else out_file + ".csv", "w")
+
+    if len(records) == 0:
+        return
+    writer = csv.DictWriter(fh, fieldnames=records[0].keys())
+    writer.writeheader()
+    writer.writerows(records)
 
 
 def main():
     import argparse
-    parser = argparse.ArgumentParser(description='Simple tool for fetching data from database',
-                                     formatter_class=argparse.RawTextHelpFormatter,
-                                     epilog = 'To specify database, user name and password, ' + \
-                                     'use "iocbio-kinetics --db"')
-    parser.add_argument('sql_file', type=str, help='Input SQL query file')
-    parser.add_argument('out_file', type=str, help='Output CSV file or - for stdout output')
+
+    parser = argparse.ArgumentParser(
+        description="Simple tool for fetching data from database",
+        formatter_class=argparse.RawTextHelpFormatter,
+        epilog="To specify database, user name and password, " + 'use "iocbio-kinetics --db"',
+    )
+    parser.add_argument("sql_file", type=str, help="Input SQL query file")
+    parser.add_argument("out_file", type=str, help="Output CSV file or - for stdout output")
     args = parser.parse_args()
 
     # opening sql file
-    with open(args.sql_file, 'r') as f:
+    with open(args.sql_file, "r") as f:
         s = f.read()
 
     r = fetch(s)
@@ -88,5 +95,5 @@ def main():
 
 
 # if run as a script
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
