@@ -27,6 +27,17 @@ class DatabaseInterface(iocdb.DatabaseInterface):
     settings_compname = "iocbio"
     settings_appname = "kinetics"
 
+    @staticmethod
+    def remove_login(username=None):
+        """Remove all saved login information"""
+        iocdb.DatabaseInterface.remove_login(
+            DatabaseInterface.settings_compname, DatabaseInterface.settings_appname, username
+        )
+
+    @staticmethod
+    def settings():
+        return iocdb.DatabaseInterface.settings(DatabaseInterface.settings_compname, DatabaseInterface.settings_appname)
+
     def __init__(self):
         iocdb.DatabaseInterface.__init__(self, self.settings_compname, self.settings_appname)
 
@@ -42,16 +53,3 @@ class DatabaseInterface(iocdb.DatabaseInterface):
             pass
         else:
             raise RuntimeError("This version (%s) of database schema is not supported" % version)
-
-    @staticmethod
-    def get_database():
-        return iocdb.DatabaseInterface.get_database(DatabaseInterface.settings_compname, DatabaseInterface.settings_appname)
-
-    @staticmethod
-    def remove_login(username = None):
-        """Remove all saved login information"""
-        iocdb.DatabaseInterface.remove_login(DatabaseInterface.settings_compname, DatabaseInterface.settings_appname, username)
-
-    @staticmethod
-    def settings():
-        return iocdb.DatabaseInterface.settings(DatabaseInterface.settings_compname, DatabaseInterface.settings_appname)
